# PreviousPageEmail

The first email on the current page. Can be used with \"backwards\" as the search_direction_query parameter to retrieve the previous page's entries. Is an empty string if the current page is the first page. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The first email on the current page. Can be used with \&quot;backwards\&quot; as the search_direction_query parameter to retrieve the previous page&#39;s entries. Is an empty string if the current page is the first page.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


